A geometric angle.
A pair of a getter and a setter, encapsulating a reference to some value.
A widget that performs an action when pressed/tapped.
A C/FFI-compatible wrapper around Root<T>.
A capsule shape.
A circular shape.
An RGBA color.
A context used during rendering that tracks the path to the current view and
holds a reference to internal storage.
The difference between two values.
An event emitted during a drag gesture.
A gesture recognizing a drag.
An elliptic shape.
A shape that fills its content using a given style.
A group of views that is dynamically computed from a given collection.
A view recognizing a gesture.
A view that lays out its children horizontally.
A view that handles events using a provided closure.
A borrowed path of ids.
An owned path of ids.
A value with an id.
A conditional view that can take on one of at most two branches, depending
on a boolean condition.
Insets along each edge of a rectangle.
A view that arranges its children in a stylized list.
A view that applies a modifier.
A view that lays out its children on top of each other.
A view that lets the user choose a value.
A rectangular shape.
The central state of a Nuit application.
A rectangular shape with rounded corners.
A circular sector shape.
A wrapper around a value managed by nuit.
A key that uniquely identifies a value in a storage.
A facility that manages view state internally.
A shape that strokes its outline using a given style.
A gesture recognizing a tap.
A text label.
A user-modifiable text field.
A point in normalized 2D space ([0, 1] x [0, 1])
A view that lays out its children vertically.
A 2D vector (or position).
A view that lays out its children on top of each other.